OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Creating account failed: " : "Crearea contului a eșuat:",
    "Name" : "Nume",
    "Mail Address" : "Adresă Mail",
    "Password" : "Parolă",
    "Manual" : "Manual",
    "None" : "Niciuna",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Parolă SMTP",
    "Save" : "Salvează",
    "Connect" : "Conectare",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Select account" : "Selectează cont",
    "Subject" : "Subiect",
    "Sending …" : "Se trimite...",
    "Go back" : "Înapoi",
    "Retry" : "Reîncearcă",
    "Message sent!" : "Mesaj trimis!",
    "Send" : "Trimite",
    "Favorite" : "Favorite",
    "Select" : "Select",
    "Delete" : "Șterge",
    "Important" : "Important",
    "Favorites" : "Favorite",
    "Other" : "Altele",
    "to" : "către",
    "Reply" : "Răspunde",
    "Unnamed" : "Fără nume",
    "Choose a folder to store the attachment in" : "Alege un dosar în care să stochez atașamentul",
    "Settings" : "Setări",
    "Quota" : "Procent",
    "Add folder" : "Add folder",
    "Remove account" : "Sterge contul",
    "Loading …" : "Se încarcă…",
    "Cancel" : "Anulează",
    "Show all folders" : "Arată toate directoarele",
    "Mark all as read" : "Marcaţi tot ca fiind citit",
    "Clear cache" : "Șterge cache",
    "Signature" : "Semnătură",
    "General" : "General",
    "User" : "Utilizator",
    "Host" : "Gazdă",
    "Port" : "Portul",
    "Search" : "Caută",
    "Refresh" : "Reîmprospătează",
    "All" : "Toate ",
    "Archive" : "Arhivă",
    "Drafts" : "Schițe",
    "Sent" : "Trimis",
    "Trash" : "Gunoi",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Eroare la încărcarea mesajelor",
    "Redirect" : "Deviere",
    "Continue to %s" : "Continuă către %s"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
